.. expect: role missing opening tag colon
.. expect: default role used (hint: for inline literals, use double backticks) (default-role)

This attribute is to match :attr:`importlib.machinery.ModuleSpec.loader`
as stored in the attr:`__spec__` object.
